@@ -319,6 +319,7 @@ def get_interactive_deposit(request: Request) -> Response:
     asset = args_or_error["asset"]
     callback = args_or_error["callback"]
     amount = args_or_error["amount"]
+    lang = args_or_error["lang"]
     if args_or_error["on_change_callback"]:
         transaction.on_change_callback = args_or_error["on_change_callback"]
         transaction.save()
@@ -330,6 +331,7 @@ def get_interactive_deposit(request: Request) -> Response:
             asset=asset,
             amount=amount,
             callback=callback,
+            lang=lang,
         )
     except NotImplementedError:
         pass
@@ -396,10 +398,13 @@ def get_interactive_deposit(request: Request) -> Response:
         **content_from_anchor,
     }
 
-    return Response(
+    response = Response(
         content,
         template_name=content_from_anchor.get("template_name", "polaris/deposit.html"),
     )
+    if lang:
+        response.set_cookie(django_settings.LANGUAGE_COOKIE_NAME, lang)
+    return response
 
 
 @api_view(["POST"])
@@ -414,7 +419,9 @@ def deposit(token: SEP10Token, request: Request) -> Response:
     returns the URL entry-point for the interactive flow.
     """
     asset_code = request.data.get("asset_code")
-    destination_account = request.data.get("account")
+    destination_account = (
+        request.data.get("account") or token.muxed_account or token.account
+    )
     lang = request.data.get("lang")
     sep9_fields = extract_sep9_fields(request.data)
     claimable_balance_supported = request.data.get("claimable_balance_supported")
@@ -440,10 +447,8 @@ def deposit(token: SEP10Token, request: Request) -> Response:
         activate_lang_for_request(lang)
 
     # Verify that the request is valid.
-    if not all([asset_code, destination_account]):
-        return render_error_response(
-            _("`asset_code` and `account` are required parameters")
-        )
+    if not asset_code:
+        return render_error_response(_("`asset_code` is required"))
 
     # Ensure memo won't cause stellar transaction to fail when submitted
     try:
@@ -539,6 +544,7 @@ def deposit(token: SEP10Token, request: Request) -> Response:
         asset_code=asset_code,
         op_type=settings.OPERATION_DEPOSIT,
         amount=amount,
+        lang=lang,
     )
     return Response(
         {"type": "interactive_customer_info_needed", "url": url, "id": transaction_id},
